The query module
================

.. automodule:: parce.query
    :members:
    :special-members: __getitem__, __call__, __bool__
    :exclude-members: query, pquery
    :undoc-members:
    :show-inheritance:

